var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var basic_auth_exports = {};
__export(basic_auth_exports, {
  BasicAuth: () => BasicAuth
});
module.exports = __toCommonJS(basic_auth_exports);
var import_auth = require("@nocobase/auth");
var import_crypto = __toESM(require("crypto"));
var import_preset = require("../preset");
class BasicAuth extends import_auth.BaseAuth {
  constructor(config) {
    const userCollection = config.ctx.db.getCollection("users");
    super({ ...config, userCollection });
  }
  async validate() {
    const ctx = this.ctx;
    const {
      values: {
        account,
        // Username or email
        email,
        // Old parameter, compatible with old api
        password
      }
    } = ctx.action.params;
    if (!account && !email) {
      ctx.throw(400, ctx.t("Please enter your username or email", { ns: import_preset.namespace }));
    }
    const filter = email ? { email } : {
      $or: [{ username: account }, { email: account }]
    };
    const user = await this.userRepository.findOne({
      filter
    });
    if (!user) {
      ctx.throw(401, ctx.t("The username or email is incorrect, please re-enter", { ns: import_preset.namespace }));
    }
    const field = this.userCollection.getField("password");
    const valid = await field.verify(password, user.password);
    if (!valid) {
      ctx.throw(401, ctx.t("The password is incorrect, please re-enter", { ns: import_preset.namespace }));
    }
    return user;
  }
  async signUp() {
    var _a;
    const ctx = this.ctx;
    const options = ((_a = this.authenticator.options) == null ? void 0 : _a.public) || {};
    if (!options.allowSignUp) {
      ctx.throw(403, ctx.t("Not allowed to sign up", { ns: import_preset.namespace }));
    }
    const User = ctx.db.getRepository("users");
    const { values } = ctx.action.params;
    const { username, password, confirm_password } = values;
    if (!/^[^@.<>"'/]{2,16}$/.test(username)) {
      ctx.throw(400, ctx.t("Please enter a valid username", { ns: import_preset.namespace }));
    }
    if (password !== confirm_password) {
      ctx.throw(400, ctx.t("The password is inconsistent, please re-enter", { ns: import_preset.namespace }));
    }
    const user = await User.create({ values: { username, password } });
    return user;
  }
  async lostPassword() {
    const ctx = this.ctx;
    const {
      values: { email }
    } = ctx.action.params;
    if (!email) {
      ctx.throw(400, ctx.t("Please fill in your email address", { ns: import_preset.namespace }));
    }
    const user = await this.userRepository.findOne({
      where: {
        email
      }
    });
    if (!user) {
      ctx.throw(401, ctx.t("The email is incorrect, please re-enter", { ns: import_preset.namespace }));
    }
    user.resetToken = import_crypto.default.randomBytes(20).toString("hex");
    await user.save();
    return user;
  }
  async resetPassword() {
    const ctx = this.ctx;
    const {
      values: { email, password, resetToken }
    } = ctx.action.params;
    const user = await this.userRepository.findOne({
      where: {
        email,
        resetToken
      }
    });
    if (!user) {
      ctx.throw(404);
    }
    user.token = null;
    user.resetToken = null;
    user.password = password;
    await user.save();
    return user;
  }
  async getUserByResetToken() {
    const ctx = this.ctx;
    const { token } = ctx.action.params;
    const user = await this.userRepository.findOne({
      where: {
        resetToken: token
      }
    });
    if (!user) {
      ctx.throw(401);
    }
    return user;
  }
  async changePassword() {
    const ctx = this.ctx;
    const {
      values: { oldPassword, newPassword }
    } = ctx.action.params;
    const currentUser = ctx.auth.user;
    if (!currentUser) {
      ctx.throw(401);
    }
    let key;
    if (currentUser.username) {
      key = "username";
    } else {
      key = "email";
    }
    const user = await this.userRepository.findOne({
      where: {
        [key]: currentUser[key]
      }
    });
    const pwd = this.userCollection.getField("password");
    const isValid = await pwd.verify(oldPassword, user.password);
    if (!isValid) {
      ctx.throw(401, ctx.t("The password is incorrect, please re-enter", { ns: import_preset.namespace }));
    }
    user.password = newPassword;
    await user.save();
    return currentUser;
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  BasicAuth
});
